package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.SamplingPlan;

public interface ISamplingPlanService {
    public SamplingPlan selectSamplingPlanByObjId(Long objId);

    public List<SamplingPlan> selectSamplingPlanList(SamplingPlan samplingPlan);

    public int insertSamplingPlan(SamplingPlan samplingPlan);

    public int updateSamplingPlan(SamplingPlan samplingPlan);

    public int deleteSamplingPlanByObjIds(Long[] objIds);

    public int deleteSamplingPlanByObjId(Long objId);
}
