package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.SamplingPlan;
import com.aucma.base.service.ISamplingPlanService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/samplingPlan" )
public class SamplingPlanController extends BaseController {
    @Autowired
    private ISamplingPlanService samplingPlanService;

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(SamplingPlan samplingPlan) {
        startPage();
        List<SamplingPlan> list = samplingPlanService.selectSamplingPlanList(samplingPlan);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:export')" )
    @Log(title = "抽样方案" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, SamplingPlan samplingPlan) {
        List<SamplingPlan> list = samplingPlanService.selectSamplingPlanList(samplingPlan);
        ExcelUtil<SamplingPlan> util = new ExcelUtil<SamplingPlan>(SamplingPlan. class);
        util.exportExcel(response, list, "抽样方案数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(samplingPlanService.selectSamplingPlanByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:add')" )
    @Log(title = "抽样方案" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SamplingPlan samplingPlan) {
        samplingPlan.setCreatedTime(DateUtils.getNowDate());
        return toAjax(samplingPlanService.insertSamplingPlan(samplingPlan));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:edit')" )
    @Log(title = "抽样方案" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SamplingPlan samplingPlan) {
        samplingPlan.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(samplingPlanService.updateSamplingPlan(samplingPlan));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:remove')" )
    @Log(title = "抽样方案" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(samplingPlanService.deleteSamplingPlanByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingPlan:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(SamplingPlan samplingPlan) {
        List<SamplingPlan> list = samplingPlanService.selectSamplingPlanList(samplingPlan);
        return getDataTable(list);
    }
}
